# pythonic-template

A template repository for pythonic coding.

## Usage

Use the commands below to add git hooks to local git configuration.

```bash
cd .githooks
git config core.hooksPath .githooks
```
